@@ -12,27 +12,18 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import pecan.deploy
-from oslo_config import cfg
 from oslo_log import log as logging
+import pecan.deploy
 
+import designate.conf
+
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
-OPTS = [
-    cfg.ListOpt('enabled-extensions-admin', default=[],
-                help='Enabled Admin API Extensions'),
-    cfg.IntOpt('default-limit-admin', default=20,
-               help='Default per-page limit for the Admin API, a value of None'
-                    ' means show all results by default'),
-    cfg.IntOpt('max-limit-admin', default=1000,
-               help='Max per-page limit for the Admin API'),
-]
-
-cfg.CONF.register_opts(OPTS, group='service:api')
-
 
 def factory(global_config, **local_conf):
-    if not cfg.CONF['service:api'].enable_api_admin:
+    if not CONF['service:api'].enable_api_admin:
         def disabled_app(environ, start_response):
             status = '404 Not Found'
             start_response(status, [])
