@@ -15,14 +15,11 @@
 # under the License.
 
 from pecan import expose
-from oslo_log import log as logging
 
 from designate import exceptions
 
-LOG = logging.getLogger(__name__)
 
-
-class ErrorsController(object):
+class ErrorsController:
 
     @expose(content_type='text/plain')
     @expose(content_type='text/dns')
