@@ -13,10 +13,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo_log import log as logging
 import pecan
 
-from designate import utils
 from designate.api.v2.controllers import rest
+from designate import utils
+
+LOG = logging.getLogger(__name__)
 
 
 class XfrController(rest.RestController):
@@ -29,6 +32,10 @@ class XfrController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
+        zone = self.central_api.get_zone(context, zone_id)
+
+        LOG.info("Triggered XFR for %(zone)s", {'zone': zone})
+
         self.central_api.xfr_zone(context, zone_id)
         response.status_int = 202
 
