@@ -17,10 +17,10 @@ import sys
 
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
 from designate.mdns import service as mdns_service
 from designate import service
 from designate import utils
@@ -28,15 +28,13 @@ from designate import version
 
 
 CONF = designate.conf.CONF
-CONF.import_opt('workers', 'designate.mdns', group='service:mdns')
 
 
 def main():
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
-    gmr.TextGuruMeditation.setup_autorun(version)
-
-    hookpoints.log_hook_setup()
+    gmr_opts.set_defaults(CONF)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     server = mdns_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
