@@ -46,7 +46,7 @@ class DesignateContext(context.RequestContext):
                  edit_managed_records=False, hide_counts=False,
                  client_addr=None, user_auth_plugin=None,
                  hard_delete=False, delete_shares=False, **kwargs):
-        super(DesignateContext, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.user_auth_plugin = user_auth_plugin
         self.service_catalog = service_catalog
@@ -63,12 +63,10 @@ class DesignateContext(context.RequestContext):
         self.delete_shares = delete_shares
 
     def deepcopy(self):
-        d = self.to_dict()
-
-        return self.from_dict(d)
+        return self.from_dict(self.to_dict())
 
     def to_dict(self):
-        d = super(DesignateContext, self).to_dict()
+        d = super().to_dict()
 
         # Override the user_identity field to account for TSIG. When a TSIG key
         # is used as authentication e.g. via MiniDNS, it will act as a form
@@ -81,9 +79,6 @@ class DesignateContext(context.RequestContext):
         user_idt = (
             self.user_idt_format.format(
                 user=user,
-                # TODO(johnsom) Remove tenant once oslo.context>=4.0.0 is
-                #               the lower bound version.
-                tenant=self.project_id or '-',
                 project_id=self.project_id or '-',
                 domain=self.domain_id or '-',
                 user_domain=self.user_domain_id or '-',
@@ -92,9 +87,6 @@ class DesignateContext(context.RequestContext):
 
         # Update the dict with Designate specific extensions and overrides
         d.update({
-            # TODO(johnsom) Remove project_id once oslo.context>=4.0.0 is
-            #               the lower bound version.
-            'project_id': self.project_id,
             'user_identity': user_idt,
             'original_project_id': self.original_project_id,
             'service_catalog': self.service_catalog,
@@ -120,8 +112,6 @@ class DesignateContext(context.RequestContext):
 
         # NOTE(kiall): Ugly - required to match http://tinyurl.com/o3y8qmw
         context.roles.append('admin')
-        if policy.enforce_new_defaults():
-            context.system_scope = 'all'
 
         if show_deleted is not None:
             context.show_deleted = show_deleted
@@ -221,18 +211,17 @@ class DesignateContext(context.RequestContext):
     def get_auth_plugin(self):
         if self.user_auth_plugin:
             return self.user_auth_plugin
-        else:
-            return _ContextAuthPlugin(self.auth_token, self.service_catalog)
+        return _ContextAuthPlugin(self.auth_token, self.service_catalog)
 
 
 class _ContextAuthPlugin(plugin.BaseAuthPlugin):
     """A keystoneauth auth plugin that uses the values from the Context.
     Ideally we would use the plugin provided by auth_token middleware however
-    this plugin isn't serialized yet so we construct one from the serialized
+    this plugin isn't serialized yet, so we construct one from the serialized
     auth data.
     """
     def __init__(self, auth_token, sc):
-        super(_ContextAuthPlugin, self).__init__()
+        super().__init__()
 
         self.auth_token = auth_token
         self.service_catalog = ksa_service_catalog.ServiceCatalogV2(sc)
@@ -240,26 +229,13 @@ class _ContextAuthPlugin(plugin.BaseAuthPlugin):
     def get_token(self, *args, **kwargs):
         return self.auth_token
 
-    def get_endpoint(self, session, **kwargs):
-        endpoint_data = self.get_endpoint_data(session, **kwargs)
-        if not endpoint_data:
-            return None
-        return endpoint_data.url
-
-    def get_endpoint_data(self, session,
-                          endpoint_override=None,
-                          discover_versions=True,
-                          **kwargs):
-        urlkw = {}
-        for k in ('service_type', 'service_name', 'service_id', 'endpoint_id',
-                  'region_name', 'interface'):
-            if k in kwargs:
-                urlkw[k] = kwargs[k]
-
-        endpoint = endpoint_override or self.service_catalog.url_for(**urlkw)
-        return super(_ContextAuthPlugin, self).get_endpoint_data(
-            session, endpoint_override=endpoint,
-            discover_versions=discover_versions, **kwargs)
+    def get_endpoint(self, session, service_type=None, interface=None,
+                     region_name=None, service_name=None, **kwargs):
+        endpoint = self.service_catalog.url_for(
+            service_type=service_type, service_name=service_name,
+            interface=interface, region_name=region_name
+        )
+        return self.get_endpoint_data(session, endpoint_override=endpoint).url
 
 
 def get_current():
