@@ -12,7 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from designate.exceptions import InvalidObject
 from designate.objects import base
 from designate.objects import fields
 from designate.objects.record import Record
@@ -29,53 +28,63 @@ class TXT(Record):
         'txt_data': fields.TxtField()
     }
 
-    def _to_string(self):
-        return self.txt_data
-
     @staticmethod
     def _is_wrapped_in_double_quotes(value):
         return value.startswith('"') and value.endswith('"')
 
+    @staticmethod
+    def _is_missing_double_quote(value):
+        return ((value.startswith('"') and not value.endswith('"')) or
+                (not value.startswith('"') and value.endswith('"')))
+
     def _validate_record_single_string(self, value):
         if len(value) > 255:
-            err = ("Any TXT record string exceeding "
-                   "255 characters has to be split.")
-            raise InvalidObject(err)
+            raise ValueError(
+                'Any TXT record string exceeding 255 characters has to be '
+                'split.'
+            )
+
+        if self._is_missing_double_quote(value):
+            raise ValueError(
+                'TXT record is missing a double quote either at beginning '
+                'or at end.'
+            )
 
         if not self._is_wrapped_in_double_quotes(value):
             # value with spaces should be quoted as per RFC1035 5.1
             for element in value:
                 if element.isspace():
-                    err = ("Empty spaces are not allowed in TXT record, "
-                           "unless wrapped in double quotes.")
-                    raise InvalidObject(err)
+                    raise ValueError(
+                        'Empty spaces are not allowed in TXT record, '
+                        'unless wrapped in double quotes.'
+                    )
         else:
             # quotes within value should be escaped with backslash
             strip_value = value.strip('"')
             for index, char in enumerate(strip_value):
                 if char == '"':
                     if strip_value[index - 1] != "\\":
-                        err = ("Quotation marks should be escaped with "
-                               "backslash.")
-                        raise InvalidObject(err)
+                        raise ValueError(
+                            'Quotation marks should be escaped with backslash.'
+                        )
 
-    def _from_string(self, value):
+    def from_string(self, value):
         if len(value) > 255:
             # expecting record containing multiple strings as
             # per rfc7208 3.3 and rfc1035 3.3.14
             stripped_value = value.strip('"')
             if (not self._is_wrapped_in_double_quotes(value) and
                     '" "' not in stripped_value):
-                err = ("TXT record strings over 255 characters "
-                       "have to be split into multiple strings "
-                       "wrapped in double quotes.")
-                raise InvalidObject(err)
+                raise ValueError(
+                    'TXT record strings over 255 characters have to be split '
+                    'into multiple strings wrapped in double quotes.'
+                )
 
             record_strings = stripped_value.split('" "')
             for record_string in record_strings:
                 # add back the delimiting quotes after
                 # strip and split for each string
-                record_string = '"{}"'.format(record_string)
+                record_string = f'"{record_string}"'
                 # further validate each string individually
                 self._validate_record_single_string(value=record_string)
         else:
