@@ -24,12 +24,12 @@ from designate.backend import impl_akamai_v2 as akamai
 from designate import context
 from designate import exceptions
 from designate import objects
-from designate.tests import fixtures
+from designate.tests import base_fixtures
 
 
 class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(AkamaiBackendTestCase, self).setUp()
+        super().setUp()
 
         self.admin_context = mock.Mock()
         mock.patch.object(
@@ -67,9 +67,20 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
         response._content = json.dumps(json_data or {}).encode('utf-8')
         return response
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
+    def test_missing_library(self, mock_import):
+        mock_import.return_value = None
+        self.assertRaises(
+            exceptions.Backend,
+            akamai.AkamaiBackend,
+            objects.PoolTarget.from_dict(self.target)
+        )
+
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_create_zone_missed_contract_id(self, mock_post, mock_auth):
+    def test_create_zone_missed_contract_id(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         self.target['options'].remove(
             {'key': 'akamai_contract_id', 'value': 'G-XYW'})
         backend = akamai.AkamaiBackend(
@@ -81,7 +92,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             client_token='client_token'
         )
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.assertRaisesRegex(
                 exceptions.Backend,
                 'contractId is required for zone creation',
@@ -89,9 +100,11 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
 
         mock_post.assert_not_called()
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_create_zone(self, mock_post, mock_auth):
+    def test_create_zone(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
@@ -101,7 +114,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             client_token='client_token'
         )
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             backend.create_zone(self.admin_context, self.zone)
 
         project_id = self.admin_context.project_id or self.zone.tenant_id
@@ -118,9 +131,11 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_create_zone_duplicate_zone(self, mock_post, mock_auth):
+    def test_create_zone_duplicate_zone(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
@@ -132,7 +147,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
 
         mock_post.return_value = self.gen_response(409, 'Conflict')
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             backend.create_zone(self.admin_context, self.zone)
 
         project_id = self.admin_context.project_id or self.zone.tenant_id
@@ -149,9 +164,11 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_create_zone_with_tsig_key(self, mock_post, mock_auth):
+    def test_create_zone_with_tsig_key(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         self.target['options'].extend([
             {'key': 'tsig_key_name', 'value': 'test_key'},
             {'key': 'tsig_key_algorithm', 'value': 'hmac-sha512'},
@@ -166,7 +183,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             client_token='client_token'
         )
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             backend.create_zone(self.admin_context, self.zone)
 
         project_id = self.admin_context.project_id or self.zone.tenant_id
@@ -189,14 +206,15 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_create_zone_raise_error(self, mock_post, mock_auth):
+    def test_create_zone_raise_error(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -209,7 +227,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
         mock_post.return_value = self.gen_response(
             400, 'Bad Request', json_data)
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.assertRaisesRegex(
                 exceptions.Backend,
                 'Zone creation failed due to: Missed A option',
@@ -229,14 +247,15 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_force_delete_zone(self, mock_post, mock_auth):
+    def test_force_delete_zone(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -244,7 +263,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
 
         mock_post.return_value = self.gen_response(200, 'Success')
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             backend.delete_zone(self.admin_context, self.zone)
 
         mock_post.assert_called_once_with(
@@ -257,14 +276,15 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones/delete-requests'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_force_delete_zone_raise_error(self, mock_post, mock_auth):
+    def test_force_delete_zone_raise_error(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -273,7 +293,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
         mock_post.return_value = self.gen_response(
             403, 'Bad Request', {'detail': 'Unexpected error'})
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.assertRaisesRegex(
                 exceptions.Backend,
                 'Zone deletion failed due to: Unexpected error',
@@ -289,14 +309,15 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones/delete-requests'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_force_delete_zone_raise_error_404(self, mock_post, mock_auth):
+    def test_force_delete_zone_raise_error_404(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -305,7 +326,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
         mock_post.return_value = self.gen_response(
             404, 'Bad Request', {'detail': 'Unexpected error'})
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             backend.delete_zone(self.admin_context, self.zone)
 
         mock_post.assert_called_once_with(
@@ -318,15 +339,16 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             url='https://host_value/config-dns/v2/zones/delete-requests'
         )
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
     @mock.patch.object(akamai.requests.Session, 'get')
-    def test_soft_delete_zone(self, mock_get, mock_post, mock_auth):
+    def test_soft_delete_zone(self, mock_get, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -346,8 +368,8 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             self.gen_response(200, 'Success', {'isComplete': True})
         ]
 
-        with fixtures.random_seed(0), mock.patch.object(akamai.time,
-                                                        'sleep') as mock_sleep:
+        with base_fixtures.random_seed(0), mock.patch.object(
+                akamai.time, 'sleep') as mock_sleep:
             mock_sleep.return_value = None
             backend.delete_zone(self.admin_context, self.zone)
 
@@ -369,16 +391,17 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             )
         ])
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
     @mock.patch.object(akamai.requests.Session, 'get')
     def test_soft_delete_zone_failed_after_10_attempts(
-            self, mock_get, mock_post, mock_auth):
+            self, mock_get, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
         mock_auth.EdgeGridAuth.assert_called_once_with(
-
             access_token='access_token',
             client_secret='client_secret',
             client_token='client_token'
@@ -396,8 +419,8 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             self.gen_response(200, 'Success', {'isComplete': False})
         ]
 
-        with fixtures.random_seed(0), mock.patch.object(akamai.time,
-                                                        'sleep') as mock_sleep:
+        with base_fixtures.random_seed(0), mock.patch.object(
+                akamai.time, 'sleep') as mock_sleep:
             mock_sleep.return_value = None
             self.assertRaisesRegex(
                 exceptions.Backend,
@@ -422,9 +445,11 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             )
         ])
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_soft_delete_zone_raise_error(self, mock_post, mock_auth):
+    def test_soft_delete_zone_raise_error(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
@@ -442,7 +467,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             self.gen_response(409, 'Conflict', {'detail': 'Intenal Error'})
         ]
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.assertRaisesRegex(
                 exceptions.Backend,
                 'Zone deletion failed due to: Intenal Error',
@@ -461,9 +486,11 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             )
         ])
 
-    @mock.patch.object(akamai, 'edgegrid')
+    @mock.patch.object(akamai.importutils, 'try_import')
     @mock.patch.object(akamai.requests.Session, 'post')
-    def test_soft_delete_zone_missed_request_id(self, mock_post, mock_auth):
+    def test_soft_delete_zone_missed_request_id(self, mock_post, mock_import):
+        mock_auth = mock.Mock()
+        mock_import.return_value = mock_auth
         backend = akamai.AkamaiBackend(
             objects.PoolTarget.from_dict(self.target)
         )
@@ -481,7 +508,7 @@ class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
             self.gen_response(200, 'Success')
         ]
 
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.assertRaisesRegex(
                 exceptions.Backend,
                 'Zone deletion failed due to: requestId missed in response',
