@@ -16,13 +16,14 @@
 import time
 
 import futurist
-from oslo_config import cfg
 from oslo_log import log as logging
 
+import designate.conf
 from designate import exceptions
 
+
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 
 
 def default_executor():
@@ -32,7 +33,7 @@ def default_executor():
     return futurist.GreenThreadPoolExecutor(CONF['service:worker'].threads)
 
 
-class Executor(object):
+class Executor:
     """
     Object to facilitate the running of a task, or a set of tasks on an
     executor that can map multiple tasks across a configurable number of
