@@ -13,22 +13,24 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
+from designate.common.decorators import rpc as rpc_decorator
 from designate.common import profiler
-from designate.loggingutils import rpc_logging
+import designate.conf
 from designate import rpc
 
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 WORKER_API = None
 
 
 @profiler.trace_cls("rpc")
-@rpc_logging(LOG, 'worker')
-class WorkerAPI(object):
+@rpc_decorator.rpc_logging(LOG, 'worker')
+class WorkerAPI:
     """
     Client side of the worker RPC API.
 
@@ -41,7 +43,7 @@ class WorkerAPI(object):
     RPC_API_VERSION = '1.2'
 
     def __init__(self, topic=None):
-        self.topic = topic if topic else cfg.CONF['service:worker'].topic
+        self.topic = topic if topic else CONF['service:worker'].topic
 
         target = messaging.Target(topic=self.topic,
                                   version=self.RPC_API_VERSION)
