@@ -29,6 +29,9 @@ function cleanup_designate {
 
 # configure_designate - Set config files, create data dirs, etc
 function configure_designate {
+    local rootwrap_sudoer_cmd
+    local tempfile
+
     [ ! -d $DESIGNATE_CONF_DIR ] && sudo mkdir -m 755 -p $DESIGNATE_CONF_DIR
     sudo chown $STACK_USER $DESIGNATE_CONF_DIR
 
@@ -68,6 +71,9 @@ function configure_designate {
 
     # Central Configuration
     iniset $DESIGNATE_CONF service:central workers $API_WORKERS
+    if [[ -n "$SCHEDULER_FILTERS" ]]; then
+        iniset $DESIGNATE_CONF service:central scheduler_filters $SCHEDULER_FILTERS
+    fi
 
     # mDNS Configuration
     iniset $DESIGNATE_CONF service:mdns listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_MDNS}
@@ -89,15 +95,15 @@ function configure_designate {
     iniset $DESIGNATE_CONF oslo_messaging_notifications topics "$DESIGNATE_NOTIFICATION_TOPICS"
 
     # Root Wrap
-    sudo cp $DESIGNATE_DIR/etc/designate/rootwrap.conf.sample $DESIGNATE_ROOTWRAP_CONF
+    sudo cp $DESIGNATE_DIR/etc/designate/rootwrap.conf $DESIGNATE_ROOTWRAP_CONF
     iniset $DESIGNATE_ROOTWRAP_CONF DEFAULT filters_path $DESIGNATE_DIR/etc/designate/rootwrap.d root-helper
 
     # Oslo Concurrency
     iniset $DESIGNATE_CONF oslo_concurrency lock_path "$DESIGNATE_STATE_PATH"
 
     # Set up the rootwrap sudoers for designate
-    local rootwrap_sudoer_cmd="$DESIGNATE_BIN_DIR/designate-rootwrap $DESIGNATE_ROOTWRAP_CONF *"
-    local tempfile=`mktemp`
+    rootwrap_sudoer_cmd="$DESIGNATE_BIN_DIR/designate-rootwrap $DESIGNATE_ROOTWRAP_CONF *"
+    tempfile=`mktemp`
     echo "$STACK_USER ALL=(root) NOPASSWD: $rootwrap_sudoer_cmd" >$tempfile
     chmod 0440 $tempfile
     sudo chown root:root $tempfile
@@ -136,7 +142,7 @@ function configure_designatedashboard {
 }
 
 # Configure the needed tempest options
-function configure_designate_tempest() {
+function configure_designate_tempest {
     if is_service_enabled tempest; then
         # Tell tempest we're available
         iniset $TEMPEST_CONFIG service_available designate True
@@ -179,10 +185,12 @@ function configure_designate_tempest() {
 # ------------------------------------------------------------------
 # service              designate  admin        # if enabled
 function create_designate_accounts {
-    if is_service_enabled designate-api; then
-        create_service_user "designate"
+    local designate_api_url
 
-        local designate_api_url="$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns"
+    if is_service_enabled designate-api; then
+        create_service_user "designate" "admin"
+
+        designate_api_url="$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns"
 
         get_or_create_service "designate" "dns" "Designate DNS Service"
         get_or_create_endpoint \
@@ -201,6 +209,27 @@ function create_designate_pool_configuration {
     if function_exists create_designate_pool_configuration_backend; then
         create_designate_pool_configuration_backend
     fi
+
+    # create the tsigkey for the secondary pool acct., if necessary.
+    if [ "$DESIGNATE_BACKEND_DRIVER" == "multipool-bind9" ] && \
+    [ -d $BIND2_CFG_DIR ] && [ -f $BIND2_TSIGKEY_FILE ]; then
+        # parse the data from the bind-2/named.conf.tsigkeys file,
+        # which was created during the init_designate_backend section.
+        NAME=`cat $BIND2_TSIGKEY_FILE | grep 'key' | \
+            awk '{split($0, a, " "); print a[2];}' | \
+            sed -e 's/^"//' -e 's/"$//'| \
+            awk '{split($0, a, "{"); print a[1];}'`
+        ALGORITHM=`cat $BIND2_TSIGKEY_FILE | grep 'algorithm' | \
+            awk '{split($0, a, " "); print a[2];}' | \
+            sed -r 's/(.*);/\1/'`
+        SECRET=`cat $BIND2_TSIGKEY_FILE | grep 'secret' | \
+            awk '{split($0, a, " "); print a[2];}' | \
+            sed -r 's/(.*);/\1/' | sed -e 's/^"//' -e 's/"$//'`
+        RESOURCE_ID=$(sudo mysql -u root -p$DATABASE_PASSWORD designate -N -e "select id from pools where name = 'secondary_pool';")
+
+        # create the openstack
+        openstack tsigkey create --name $NAME --algorithm $ALGORITHM --secret $SECRET --scope POOL --resource-id $RESOURCE_ID
+    fi
 }
 
 # init_designate - Initialize etc.
@@ -257,8 +286,8 @@ function install_designatedashboard {
     setup_dev_lib "designate-dashboard"
 
     for panel in _1710_project_dns_panel_group.py \
-                 _1721_dns_zones_panel.py \
-                 _1722_dns_reversedns_panel.py; do
+            _1721_dns_zones_panel.py \
+            _1722_dns_reversedns_panel.py; do
         ln -fs $DESIGNATEDASHBOARD_DIR/designatedashboard/enabled/$panel $HORIZON_DIR/openstack_dashboard/local/enabled/$panel
     done
 }
